@@ -287,13 +287,6 @@ extern "C"
 				 const char *policy,
 				 size_t sizeof_policy);
 
-  typedef enum gnutls_certificate_print_formats
-    {
-      GNUTLS_X509_CRT_FULL,
-      GNUTLS_X509_CRT_ONELINE,
-      GNUTLS_X509_CRT_UNSIGNED_FULL
-    } gnutls_certificate_print_formats_t;
-
   int gnutls_x509_crt_print (gnutls_x509_crt_t cert,
 			     gnutls_certificate_print_formats_t format,
 			     gnutls_datum_t *out);
@@ -335,6 +328,14 @@ extern "C"
   int gnutls_x509_dn_get_rdn_ava (gnutls_x509_dn_t dn, int irdn,
 				  int iava, gnutls_x509_ava_st *avast);
 
+  int gnutls_x509_dn_init (gnutls_x509_dn_t * dn);
+
+  int gnutls_x509_dn_import (gnutls_x509_dn_t odn,
+                             const gnutls_datum_t * data);
+
+  void gnutls_x509_dn_deinit (gnutls_x509_dn_t idn);
+
+
 /* CRL handling functions.
  */
   int gnutls_x509_crl_init (gnutls_x509_crl_t * crl);
