@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation
+ * Copyright (C) 2002, 2003, 2004, 2005, 2008 Free Software Foundation
  *
  * Author: Nikos Mavrogiannopoulos
  *
@@ -74,27 +74,10 @@ _gnutls_server_name_recv_params (gnutls_session_t session,
 	  len = _gnutls_read_uint16 (p);
 	  p += 2;
 
-	  if (len > 0)
-	    {
-	      DECR_LENGTH_RET (data_size, len, 0);
-	      server_names++;
-	      p += len;
-	    }
-	  else
-	    _gnutls_handshake_log
-	      ("HSK[%x]: Received zero size server name (under attack?)\n",
-	       session);
+	  DECR_LENGTH_RET (data_size, len, 0);
+	  server_names++;
 
-	}
-
-      /* we cannot accept more server names.
-       */
-      if (server_names > MAX_SERVER_NAME_EXTENSIONS)
-	{
-	  _gnutls_handshake_log
-	    ("HSK[%x]: Too many server names received (under attack?)\n",
-	     session);
-	  server_names = MAX_SERVER_NAME_EXTENSIONS;
+	  p += len;
 	}
 
       session->security_parameters.extensions.server_names_size =
@@ -102,6 +85,10 @@ _gnutls_server_name_recv_params (gnutls_session_t session,
       if (server_names == 0)
 	return 0;		/* no names found */
 
+      /* we cannot accept more server names.
+       */
+      if (server_names > MAX_SERVER_NAME_EXTENSIONS)
+	server_names = MAX_SERVER_NAME_EXTENSIONS;
 
       p = data + 2;
       for (i = 0; i < server_names; i++)
@@ -209,7 +196,7 @@ _gnutls_server_name_send_params (gnutls_session_t session,
 
 	      memcpy (p,
 		      session->security_parameters.extensions.
-		      server_names[0].name, len);
+		      server_names[i].name, len);
 	      p += len;
 	      break;
 	    default:
