@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Free Software Foundation
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation
  *
  * Author: Nikos Mavrogiannopoulos
  *
@@ -40,9 +40,11 @@
 #include <gnutls_state.h>
 #include <gnutls_auth_int.h>
 #include <gnutls_x509.h>
-#include <gnutls_extra_hooks.h>
 #include "x509/x509.h"
 #include "x509/mpi.h"
+#ifdef ENABLE_OPENPGP
+# include "openpgp/gnutls_openpgp.h"
+#endif
 
 /**
   * gnutls_certificate_free_keys - Used to free all the keys from a gnutls_certificate_credentials_t structure
@@ -112,6 +114,62 @@ gnutls_certificate_free_cas (gnutls_certificate_credentials_t sc)
 
 }
 
+/**
+  * gnutls_certificate_export_x509_cas - Used to export all the CAs from a gnutls_certificate_credentials_t structure
+  * @sc: is an #gnutls_certificate_credentials_t structure.
+  * @x509_ca_list: the exported CA list. Should be treated as constant
+  * @ncas: the number of exported CAs
+  *
+  * This function will export all the CAs associated
+  * with the given credentials. 
+  *
+  **/
+void
+gnutls_certificate_export_x509_cas (gnutls_certificate_credentials_t sc, 
+  gnutls_x509_crt_t **x509_ca_list, unsigned int* ncas)
+{
+  *x509_ca_list = sc->x509_ca_list;
+  *ncas = sc->x509_ncas;
+}
+
+/**
+  * gnutls_certificate_export_x509_crls - Used to export all the CRLs from a gnutls_certificate_credentials_t structure
+  * @sc: is an #gnutls_certificate_credentials_t structure.
+  * @ring: the exported keyring. Should be treated as constant
+  *
+  * This function will export the OpenPGP keyring associated
+  * with the given credentials. 
+  *
+  **/
+void
+gnutls_certificate_export_x509_crls (gnutls_certificate_credentials_t sc, 
+  gnutls_x509_crl_t **x509_crl_list, unsigned int* ncrls)
+{
+  *x509_crl_list = sc->x509_crl_list;
+  *ncrls = sc->x509_ncrls;
+}
+
+#ifdef ENABLE_OPENPGP
+
+/**
+  * gnutls_certificate_export_openpgp_keyring - Used to export the keyring from a gnutls_certificate_credentials_t structure
+  * @sc: is an #gnutls_certificate_credentials_t structure.
+  * @x509_crl_list: the exported CRL list. Should be treated as constant
+  * @ncrls: the number of exported CRLs
+  *
+  * This function will export all the CRLs associated
+  * with the given credentials. 
+  *
+  **/
+void
+gnutls_certificate_export_openpgp_keyring (gnutls_certificate_credentials_t sc, 
+  gnutls_openpgp_keyring_t *keyring)
+{
+  *keyring = sc->keyring;
+}
+
+#endif
+
 /**
   * gnutls_certificate_free_ca_names - Used to free all the CA names from a gnutls_certificate_credentials_t structure
   * @sc: is an #gnutls_certificate_credentials_t structure.
@@ -191,11 +249,8 @@ gnutls_certificate_free_credentials (gnutls_certificate_credentials_t sc)
   gnutls_certificate_free_crls (sc);
 #endif
 
-#ifndef KEYRING_HACK
-  if (_E_gnutls_openpgp_keyring_deinit)
-    _E_gnutls_openpgp_keyring_deinit( sc->keyring);
-#else
-  _gnutls_free_datum( &sc->keyring);
+#ifdef ENABLE_OPENPGP
+  gnutls_openpgp_keyring_deinit( sc->keyring);
 #endif
 
   gnutls_free (sc);
@@ -436,6 +491,7 @@ _gnutls_x509_get_raw_crt_expiration_time (const gnutls_datum_t * cert)
   return result;
 }
 
+#ifdef ENABLE_OPENPGP
 /*-
   * _gnutls_openpgp_crt_verify_peers - This function returns the peer's certificate status
   * @session: is a gnutls session
@@ -485,13 +541,8 @@ _gnutls_openpgp_crt_verify_peers (gnutls_session_t session,
 
   /* Verify certificate 
    */
-  if (_E_gnutls_openpgp_verify_key == NULL)
-    {
-      gnutls_assert ();
-      return GNUTLS_E_INIT_LIBEXTRA;
-    }
   ret =
-    _E_gnutls_openpgp_verify_key (cred, &info->raw_certificate_list[0],
+    _gnutls_openpgp_verify_key (cred, &info->raw_certificate_list[0],
 				  peer_certificate_list_size, status);
 
   if (ret < 0)
@@ -502,7 +553,7 @@ _gnutls_openpgp_crt_verify_peers (gnutls_session_t session,
 
   return 0;
 }
-
+#endif
 
 /**
   * gnutls_certificate_verify_peers2 - This function returns the peer's certificate verification status
@@ -551,8 +602,10 @@ gnutls_certificate_verify_peers2 (gnutls_session_t session,
     {
     case GNUTLS_CRT_X509:
       return _gnutls_x509_cert_verify_peers (session, status);
+#ifdef ENABLE_OPENPGP
     case GNUTLS_CRT_OPENPGP:
       return _gnutls_openpgp_crt_verify_peers (session, status);
+#endif
     default:
       return GNUTLS_E_INVALID_REQUEST;
     }
@@ -625,12 +678,12 @@ gnutls_certificate_expiration_time_peers (gnutls_session_t session)
       return _gnutls_x509_get_raw_crt_expiration_time (&info->
 						       raw_certificate_list
 						       [0]);
+#ifdef ENABLE_OPENPGP
     case GNUTLS_CRT_OPENPGP:
-      if (_E_gnutls_openpgp_get_raw_key_expiration_time == NULL)
-	return (time_t) - 1;
-      return _E_gnutls_openpgp_get_raw_key_expiration_time (&info->
+      return _gnutls_openpgp_get_raw_key_expiration_time (&info->
 							    raw_certificate_list
 							    [0]);
+#endif
     default:
       return (time_t) - 1;
     }
@@ -670,66 +723,40 @@ gnutls_certificate_activation_time_peers (gnutls_session_t session)
       return _gnutls_x509_get_raw_crt_activation_time (&info->
 						       raw_certificate_list
 						       [0]);
+#ifdef ENABLE_OPENPGP
     case GNUTLS_CRT_OPENPGP:
-      if (_E_gnutls_openpgp_get_raw_key_creation_time == NULL)
-	return (time_t) - 1;
-      return _E_gnutls_openpgp_get_raw_key_creation_time (&info->
+      return _gnutls_openpgp_get_raw_key_creation_time (&info->
 							  raw_certificate_list
 							  [0]);
+#endif
     default:
       return (time_t) - 1;
     }
 }
 
+/* Converts the first certificate for the cert_auth_info structure
+ * to a gcert.
+ */
 int
-_gnutls_raw_cert_to_gcert (gnutls_cert * gcert,
+_gnutls_get_auth_info_gcert (gnutls_cert * gcert,
 			   gnutls_certificate_type_t type,
-			   const gnutls_datum_t * raw_cert,
+			   cert_auth_info_t info,
 			   int flags /* OR of ConvFlags */ )
 {
   switch (type)
     {
     case GNUTLS_CRT_X509:
-      return _gnutls_x509_raw_cert_to_gcert (gcert, raw_cert, flags);
+      return _gnutls_x509_raw_cert_to_gcert (gcert,  &info->raw_certificate_list[0], flags);
+#ifdef ENABLE_OPENPGP
     case GNUTLS_CRT_OPENPGP:
-      if (_E_gnutls_openpgp_raw_key_to_gcert == NULL)
-	{
-	  gnutls_assert ();
-	  return GNUTLS_E_INIT_LIBEXTRA;
-	}
-      return _E_gnutls_openpgp_raw_key_to_gcert (gcert, raw_cert);
+      return _gnutls_openpgp_raw_crt_to_gcert (gcert,  &info->raw_certificate_list[0], info->use_subkey?info->subkey_id:NULL);
+#endif
     default:
       gnutls_assert ();
       return GNUTLS_E_INTERNAL_ERROR;
     }
 }
 
-int
-_gnutls_raw_privkey_to_gkey (gnutls_privkey * key,
-			     gnutls_certificate_type_t type,
-			     const gnutls_datum_t * raw_key,
-			     int key_enc /* DER or PEM */ )
-{
-  switch (type)
-    {
-    case GNUTLS_CRT_X509:
-      return _gnutls_x509_raw_privkey_to_gkey (key, raw_key, key_enc);
-    case GNUTLS_CRT_OPENPGP:
-      if (_E_gnutls_openpgp_raw_privkey_to_gkey == NULL)
-	{
-	  gnutls_assert ();
-	  return GNUTLS_E_INIT_LIBEXTRA;
-	}
-      return _E_gnutls_openpgp_raw_privkey_to_gkey (key, raw_key,
-						    (gnutls_openpgp_crt_fmt_t)
-						    key_enc);
-    default:
-      gnutls_assert ();
-      return GNUTLS_E_INTERNAL_ERROR;
-    }
-}
-
-
 /* This function will convert a der certificate to a format
  * (structure) that gnutls can understand and use. Actually the
  * important thing on this function is that it extracts the 
